\name{checkTableConsistency}
\alias{checkTableConsistency}
\title{Check consistency of input table to \code{\link{runComparison}}}
\usage{
checkTableConsistency(file.table)
}
\arguments{
  \item{file.table}{A table with columns input.files and
  (optionally) datasets, nbr.samples, repl, de.methods}
}
\value{
Returns a consistent file table.
}
\description{
Check that the dataset, nbr.samples, repl and de.methods
columns of a table are consistent with the information
provided in the input files (given in the input.files
column). If there are inconsistencies, replace the given
information with the information in the input files.
}
\examples{
\dontrun{
mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500,
                                    samples.per.cond = 5, n.diffexp = 1250,
                                    output.file = "mydata.rds")
runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma",
           Rmdfunction = "voom.limma.createRmd", output.directory = ".",
           norm.method = "TMM")
runDiffExp(data.file = "mydata.rds", result.extent = "ttest",
           Rmdfunction = "ttest.createRmd", output.directory = ".",
           norm.method = "TMM")

## A correct table
file.table <- data.frame(input.files = c("mydata_voom.limma.rds", "mydata_ttest.rds"),
                         datasets = c("mydata", "mydata"),
                         nbr.samples = c(5, 5),
                         repl = c(1, 1),
                         stringsAsFactors = FALSE)
new.table <- checkTableConsistency(file.table)
new.table

## An incorrect table
file.table <- data.frame(input.files = c("mydata_voom.limma.rds", "mydata_ttest.rds"),
                         datasets = c("mydata", "mydata"),
                         nbr.samples = c(5, 3),
                         repl = c(2, 1),
                         stringsAsFactors = FALSE)
new.table <- checkTableConsistency(file.table)
new.table
}
}
\author{
Charlotte Soneson
}

